@@ -16,6 +16,7 @@
  *
  * SPDX-License-Identifier: ISC
  */
+
 #include "../curl_setup.h"
 
 #ifndef HAVE_INET_NTOP
@@ -181,9 +182,10 @@ static char *inet_ntop6(const unsigned char *src, char *dst, size_t size)
    */
   if(best.base != -1 && (best.base + best.len) == (IN6ADDRSZ / INT16SZ))
     *tp++ = ':';
+  *tp++ = '\0';
 
   /* Check for overflow, copy, and we are done. */
-  if((size_t)(tp - tmp) >= size) {
+  if((size_t)(tp - tmp) > size) {
 #ifdef USE_WINSOCK
     errno = WSAEINVAL;
 #else
@@ -192,7 +194,7 @@ static char *inet_ntop6(const unsigned char *src, char *dst, size_t size)
     return NULL;
   }
 
-  curlx_strcopy(dst, size, tmp, tp - tmp);
+  curlx_strcopy(dst, size, tmp, strlen(tmp));
   return dst;
 }
 
